@@ -25,24 +25,29 @@
 
 #include "trayicon.h"
 
-KBlueTray::KBlueTray(QObject* parent) : QObject(parent)
+KBlueTray::KBlueTray(const QString& path, QObject* parent) : QObject(parent), agentPath(path)
 {
+
 	 modes << "Off" << "Discoverable" << "Connectable" ;
 	 adapter = 0;
-	 authagent = 0;
-	 passagent = 0;
 	 server = 0;
 	 serversession = 0;
+         agent = 0;
 	 
 	 setParent(kapp);
 
 	 tray = new QSystemTrayIcon(this);
-	 tray->setIcon(KIcon("preferences-system-bluetooth"));
+	 tray->setIcon(KIcon("kbluetooth4"));
 
 	 mainmenu = new QMenu();
 
+         QDBusConnection::systemBus().registerObject(agentPath, kapp);
+
 //	 kbluelockMenu = mainmenu->addMenu(KIcon("system-lock-screen"),i18n("KBlueLock"));
-	 kbluelockMenu = mainmenu->addMenu(KIcon("preferences-desktop-user-password"),i18n("KBlueLock"));
+
+/*       Currently no DeviceDisappeared Signal is thrown by Bluez
+
+         kbluelockMenu = mainmenu->addMenu(KIcon("preferences-desktop-user-password"),i18n("KBlueLock"));
 	 
 
 	 lockEnableAction = kbluelockMenu->addAction(KIcon("system-lock-screen"),i18n("Enable"));
@@ -52,13 +57,16 @@ KBlueTray::KBlueTray(QObject* parent) : QObject(parent)
 
 	 lockConfigureAction = kbluelockMenu->addAction(KIcon("configure"), i18n("Configure..."));
 	 connect(lockConfigureAction,SIGNAL(triggered(bool)), this, SLOT(slotConfigureKBlueLock()));
-	 lockConfigureAction->setEnabled(false);
+	 lockConfigureAction->setDisabled(true);
+*/
 
 	 sendToAction = mainmenu->addAction(KIcon("text-directory"), i18n("Send File"));
 	 connect(sendToAction, SIGNAL(triggered(bool)), this, SLOT(sendFile()));
+         sendToAction->setDisabled(false);
 
-	 wizardAction = mainmenu->addAction(KIcon("preferences-system-bluetooth"), i18n("Device Manager"));
+	 wizardAction = mainmenu->addAction(KIcon("kbluetooth4"), i18n("Device Manager"));
 	 connect(wizardAction, SIGNAL(triggered(bool)), this, SLOT(showManager()));
+         wizardAction->setDisabled(false);
 	
 	 settingsMenu = mainmenu->addMenu(KIcon("preferences-system"), i18n("Settings"));
 	
@@ -67,7 +75,7 @@ KBlueTray::KBlueTray(QObject* parent) : QObject(parent)
 	 
 	 serverAction = settingsMenu->addAction(KIcon("network-server"), i18n("Obex server"));
 	 serverAction->setCheckable(true);
-	 serverAction->setChecked(false);
+	 serverAction->setChecked(true);
 	 connect(serverAction, SIGNAL(triggered(bool)), this, SLOT(enableServer()));
 
 	 aboutAction = mainmenu->addAction(KIcon("folder-remote"),i18n("About"));
@@ -107,19 +115,22 @@ KBlueTray::KBlueTray(QObject* parent) : QObject(parent)
 	kblueLockEnabled = false;
 	
 	if ( man.bluetoothInterfaces().size() > 0 ) {
-		onlineMode(man);
+                defaultAdapterUBI = man.defaultInterface();
+		onlineMode();
 	} else {
 		offlineMode();
 	}
-	
+        
+        
+
 }
 
 KBlueTray::~KBlueTray()
 {
 
 	if (adapter) {
-		if ( adapter->isPeriodicDiscoveryActive() ) 
-			adapter->stopPeriodicDiscovery();
+                adapter->unregisterAgent(agentPath);
+		adapter->stopDiscovery();
 		delete adapter;
 	}
 
@@ -152,74 +163,80 @@ KBlueTray::~KBlueTray()
 	qDebug() << "bye bye";
 }
 
-void KBlueTray::onlineMode(Solid::Control::BluetoothManager& man)
+void KBlueTray::onlineMode()
 {
 	kDebug() << "online Mode";
-	
-	secure = man.security();
-	authagent = new AuthAgent(this);
-	secure->setAuthorizationAgent(authagent);
-	passagent = new PasskeyAgent(this);
-	secure->setPasskeyAgent(passagent);
+	Solid::Control::BluetoothManager &man = Solid::Control::BluetoothManager::self();	
+	kDebug() << "adapter size " << Solid::Control::BluetoothManager::self().bluetoothInterfaces().size();
 
 	online = true;
 	tray->setVisible(true);
 	
 	adapter = new Solid::Control::BluetoothInterface(man.defaultInterface());
-	connect(adapter,SIGNAL(nameChanged(const QString&)),this,SLOT(slotNameChanged(const QString&)));
-	connect(adapter,SIGNAL(modeChanged(Solid::Control::BluetoothInterface::Mode)),this,SLOT(slotModeChanged(Solid::Control::BluetoothInterface::Mode)));
-	connect(adapter,SIGNAL(remoteDeviceConnected(const QString&)),this,SLOT(slotRemoteDeviceConnected(const QString&)));
-	connect(adapter,SIGNAL(remoteDeviceDisconnected(const QString&)),this,SLOT(slotRemoteDeviceDisconnected(const QString&)));
+
+
+	connect(adapter,SIGNAL(propertyChanged(const QString&, const QVariant&)),this,SLOT(slotPropertyChanged(const QString&, const QVariant&)));
+
+	kDebug() << "Adapter found " << adapter->name();
+
+        adapter->registerAgent(agentPath,"DisplayYesNo");
+        agent = new Agent(kapp);
+        agent->setExitOnRelease(false);
 	
 	updateTooltip();
 	
 	sendToAction->setEnabled(true);
 	wizardAction->setEnabled(true);
 	adapterAction->setEnabled(true);
-	kbluelockMenu->setEnabled(true);
-	
-	server = new ObexServer(this, "00:00:00:00:00:00", "opp", true);
-	connect(server, SIGNAL(serverReady()), this, SLOT(slotServerReady()));
-	connect(server, SIGNAL(started()), this, SLOT(slotServerStarted()));
-	connect(server, SIGNAL(stopped()), this, SLOT(slotServerStopped()));
-	connect(server, SIGNAL(closed()), this, SLOT(slotServerClosed()));
-	connect(server, SIGNAL(sessionCreated(const QString&)), this, SLOT(slotServerSessionCreated(const QString&)));
-	connect(server, SIGNAL(sessionRemoved(const QString&)), this, SLOT(slotServerSessionRemoved(const QString&)));
-	connect(server, SIGNAL(errorOccured(const QString&, const QString&)), this, SLOT(slotServerErrorOccured(const QString&, const QString&)));
+//	kbluelockMenu->setEnabled(true);
+        settingsMenu->setEnabled(true);
+	serverAction->setChecked(true);
+
+        if (!server) {
+            server = new ObexServer(this, "00:00:00:00:00:00", "opp", true);
+            connect(server, SIGNAL(serverReady()), this, SLOT(slotServerReady()));
+            connect(server, SIGNAL(started()), this, SLOT(slotServerStarted()));
+            connect(server, SIGNAL(stopped()), this, SLOT(slotServerStopped()));
+            connect(server, SIGNAL(closed()), this, SLOT(slotServerClosed()));
+            connect(server, SIGNAL(sessionCreated(const QString&)), this, SLOT(slotServerSessionCreated(const QString&)));
+            connect(server, SIGNAL(sessionRemoved(const QString&)), this, SLOT(slotServerSessionRemoved(const QString&)));
+            connect(server, SIGNAL(errorOccured(const QString&, const QString&)), this, SLOT(slotServerErrorOccured(const QString&, const QString&)));
+        } else
+            enableServer();
+
 
 }
 
 void KBlueTray::offlineMode()
 {
 	kDebug() << "offline Mode";
+
 	online = false;
 
 	sendToAction->setEnabled(false);
 	wizardAction->setEnabled(false);
 	adapterAction->setEnabled(false);
-	kbluelockMenu->setEnabled(false);
+//	kbluelockMenu->setEnabled(false);
+	settingsMenu->setEnabled(false);
 	
 	//tray->setToolTip("No Bluetooth Adapter");
 	tray->setVisible(false);
 		
-	if (authagent) {
-		delete authagent;
-		authagent = 0;
-	}
-	if (passagent) {
-		delete passagent;
-		passagent = 0;
-	}
 	if (adapter) {
+                kDebug() << "Unregistering Agent";
+                adapter->unregisterAgent(agentPath);
 		disconnect(adapter,0,0,0);
 		delete adapter;
 		adapter = 0;
 	}
+
+        if (agent) {
+            delete agent;
+            agent = 0;
+        }
 	
 	if(server) {
-		server->close();
-		delete server;
-		server = 0;
+		server->stop();
 	}
 	
 	if(serversession) {
@@ -228,21 +245,29 @@ void KBlueTray::offlineMode()
 		delete serversession;
 		serversession = 0;
 	}
+
+
 }
 
 void KBlueTray::updateTooltip() {
 	
-	if(!adapter || !server) return;
+	if(!online) {
+		toolTipInfo = i18n("No Bluetooth Adapter");
+		return;
+	}
+
+        if(!adapter || !server ) 
+            return;
+	
 	
 	toolTipInfo = 	"<b>Name:</b> " + adapter->name() + "<br />" \
 			+	"<b>Address:</b> " + adapter->address() + "<br />" \
-			+      	"<b>Mode:</b> " + modes.at(adapter->mode()) + "<br />" \
 			+	"<b>KBlueLock:</b> ";
 
 	if (!kblueLockEnabled)
 		toolTipInfo += "Disabled"; 
 	else
-		toolTipInfo += ("Enabled for " + adapter->getRemoteName(lockDevice.split('/').at(4)));
+		toolTipInfo += ("Enabled for " + lockDeviceName);
 		
 	toolTipInfo += "<br /><b>Receiving Files:</b> ";
 	if(server) {
@@ -258,10 +283,6 @@ void KBlueTray::adapterAdded(const QString& ubi)
 {
 	 kDebug() << "adapterAdded: " << ubi;
 
-	 if ( !online ) {
-	 	kDebug() << "new default adapter UBI: " << ubi;
-		onlineMode(Solid::Control::BluetoothManager::self());
-	 }
 }
 
 void KBlueTray::adapterRemoved(const QString& ubi)
@@ -273,13 +294,17 @@ void KBlueTray::adapterRemoved(const QString& ubi)
 		offlineMode();
 		kDebug() << "default Adapter removed";
 	 }
+	updateTooltip();
 }
 
 void KBlueTray::defaultAdapterChanged(const QString& ubi)
 {
 	kDebug() << "default Adapter changed " << ubi;
-	defaultAdapterUBI = ubi;
-
+        if (!online) {
+	    kDebug() << "new default adapter UBI: " << ubi;
+    	    defaultAdapterUBI = ubi;
+            onlineMode();
+        }
 }
 
 void KBlueTray::slotQuitApp(bool /*set*/)
@@ -289,14 +314,14 @@ void KBlueTray::slotQuitApp(bool /*set*/)
 
 void KBlueTray::showAboutInfo()
 {
-        KAboutData aboutData("kbluetooth4", 0, ki18n("KBluetooth4"), "0.2",
+        KAboutData aboutData("kbluetooth4", 0, ki18n("KBluetooth4"), "0.3",
                            ki18n("KDE4 Bluetooth Framework"), KAboutData::License_GPL_V2);
         aboutData.addAuthor(ki18n("Tom Patzig"), KLocalizedString(), "tpatzig@suse.de", "http://www.kde.org/");
 	aboutData.addCredit(ki18n("Arjan Topolovec"), ki18n(""), "arjan.top@gmail.com", "");
-        aboutData.setProgramLogo(KIcon("preferences-system-bluetooth"));
+        aboutData.setProgramLogo(KIcon("kbluetooth4"));
 
         KAboutApplicationDialog about(&aboutData, mainmenu);
-//        about.setIcon( KIcon( "preferences-system-bluetooth" ) );
+//        about.setIcon( KIcon( "kbluetooth4" ) );
         about.exec();
 }
 
@@ -311,8 +336,8 @@ void KBlueTray::showAdapterInterface()
 
 void KBlueTray::showWizard()
 {
-	BTWizard wiz;
-	wiz.exec();
+//bluez4//	BTWizard wiz;
+//bluez4//	wiz.exec();
 }
 
 void KBlueTray::showManager()
@@ -322,7 +347,6 @@ void KBlueTray::showManager()
 	KProcess process;
 	process.setProgram("kbluetooth4-devicemanager");
 	process.startDetached();
-
 	
 //	manager.exec();
 }
@@ -331,22 +355,23 @@ void KBlueTray::showManager()
 
 void KBlueTray::sendFile()
 {
+// bluez4//    
 	QString fileName = KFileDialog::getOpenFileName(KUrl("./"),"*",mainmenu, tr("Select File"));
         if (!fileName.isEmpty()) {
 		fileToSend = fileName;
 		devSelector = new DeviceSel(this,QString("computer,phone").split(','));
 	 	devSelector->hideExtraCheckBox();
 		devSelector->setInfoLabel(i18n("Selecting a device starts the Filetransfer."));
-		connect(devSelector,SIGNAL(deviceSelected(const QString&,const QString&)),this,SLOT(slotSendFile(const QString&,const QString&)));
+		connect(devSelector,SIGNAL(deviceSelected(const QString&)),this,SLOT(slotSendFile(const QString&)));
 
         }
 
 
 }
 
-void KBlueTray::slotSendFile(const QString& mac,const QString& /* ubi */ )
+void KBlueTray::slotSendFile(const QString& mac)
 {
-	session = new ObexSession(this,mac,"ftp");
+	session = new ObexSession(this,adapter->address(),mac,"ftp");
 	connect(session,SIGNAL(connected()),this,SLOT(obexSessionReady()));
 
 }
@@ -373,7 +398,7 @@ void KBlueTray::slotFileSendStarted(const QString& filename ,const QString& path
 
 	progress = new QProgressDialog(i18n("Sending ") + filename,i18n("Cancel"),0,100);
 	progress->setAutoClose(true);
-	progress->setWindowIcon(KIcon("preferences-system-bluetooth"));
+	progress->setWindowIcon(KIcon("kbluetooth4"));
 	progress->show();
 	connect(progress,SIGNAL(canceled()),this,SLOT(slotFileSendCanceled()));
 	
@@ -402,8 +427,11 @@ void KBlueTray::slotFileSendFinished()
 
 	delete session;
 	session = 0;
-	
 
+        if (progress) {
+            delete progress;
+            progress = 0;
+        }
 }
 
 void KBlueTray::slotFileSendCanceled()
@@ -423,16 +451,17 @@ void KBlueTray::enableLock()
 {
 	if (lockEnableAction->isChecked() ) {
 		if (lockDevice.isEmpty()) {
+                        kDebug() << "Configuring new KBlueLock Device";
 	 	 	kblueUnlockEnabled = true;
 			lockSelector = new DeviceSel(this,QString("computer,phone").split(','));
 			lockSelector->setOkButtonText(i18n("Select"));
 			lockSelector->setInfoLabel(i18n("Selecting a device enables KBlueLock (a balloon message in the tray icon pops up when your target device is found and KBlueLock is ready).\nIf the device disappears your screen gets locked."));
 
-			connect(lockSelector,SIGNAL(deviceSelected(const QString&,const QString&)),this,SLOT(enableBlueLock(const QString&,const QString&)));
+			connect(lockSelector,SIGNAL(deviceSelected(const QString&)),this,SLOT(enableBlueLock(const QString&)));
 			connect(lockSelector,SIGNAL(selectorCancelled()),this,SLOT(slotBlueSelectorCancelled()));
 			connect(lockSelector,SIGNAL(unlockChanged(bool)),this,SLOT(slotUnlockScreenChanged(bool)));
 		} else 
-			enableBlueLock("",lockDevice);
+			enableBlueLock(lockDevice);
 
 	} else {
 		disableBlueLock();
@@ -441,32 +470,28 @@ void KBlueTray::enableLock()
 }
 
 
-void KBlueTray::enableBlueLock(QString  mac ,const QString& ubi)
+void KBlueTray::enableBlueLock(const QString&  mac)
 {
 	disconnect(lockSelector,0,0,0);
-	disconnect(adapter,SIGNAL(remoteDeviceDisappeared(const QString)),0,0);
+	disconnect(adapter,SIGNAL(deviceDisappeared(const QString)),0,0);
 
-	lockDevice = ubi;
+	lockDevice = mac;
 	if (!lockDevice.isEmpty()) {
 
-		if (mac.isEmpty())
-			mac = ubi.split('/').at(4);
+            lockConfigureAction->setEnabled(true);
 
-		lockConfigureAction->setEnabled(true);
+            kDebug() << "KBlueLock enabled";
+            kDebug() << "lockdevice: " << lockDevice;
 
-		kDebug() << "KBlueLock enabled";
-		kDebug() << "lockdevice: " << lockDevice;
-		if (! adapter->isPeriodicDiscoveryActive()) {
-			adapter->startPeriodicDiscovery();
-			kDebug() << "Periodic Discovery Started";
-			connect(adapter,SIGNAL(remoteDeviceFound(const QString&,int,int)),this,SLOT(slotTargetDeviceFound(const QString&,int,int)));
-			tray->showMessage("KBluetooth","kbluelock is looking for the target device...",
-	 	 	 	 	 	 	 	 QSystemTrayIcon::Information,30000);
-		}
+            adapter->startDiscovery();
+            kDebug() << "Periodic Discovery Started";
+            connect(adapter,SIGNAL(deviceFound( const QString&, const QMap< QString,QVariant > & )),this,SLOT(slotTargetDeviceFound(const QString&, const QMap< QString,QVariant > & )));
+            tray->showMessage("KBluetooth","kbluelock is looking for the target device...",
+                    QSystemTrayIcon::Information,30000);
 
-		connect(adapter,SIGNAL(remoteDeviceDisappeared(const QString)),this,SLOT(slotValidateLockDev(const QString&)));
-		
-		kblueLockEnabled = false;
+            connect(adapter,SIGNAL(deviceDisappeared(const QString&)),this,SLOT(slotValidateLockDev(const QString&)));
+
+            kblueLockEnabled = false;
 
 		
 	} else {
@@ -485,19 +510,17 @@ void KBlueTray::disableBlueLock()
 	
 	lockConfigureAction->setEnabled(false);
 
-	if ( adapter->isPeriodicDiscoveryActive() ) {
-		adapter->stopPeriodicDiscovery();
-		kDebug() << "Periodic Discovery Stopped";
+        adapter->stopDiscovery();
+        kDebug() << "Periodic Discovery Stopped";
 
-	}
-	disconnect(adapter,SIGNAL(remoteDeviceDisappeared(const QString)),this,SLOT(slotValidateLockDev(const QString&)));
-	disconnect(adapter,SIGNAL(remoteDeviceFound(const QString&,int,int)),this,SLOT(slotTargetDeviceFound(const QString&,int,int)));
+	disconnect(adapter,SIGNAL(deviceDisappeared(const QString&)),this,SLOT(slotValidateLockDev(const QString&)));
+	disconnect(adapter,SIGNAL(deviceFound( const QString&, const QMap< QString,QVariant > & )),this,SLOT(slotTargetDeviceFound(const QString&, const QMap< QString,QVariant > & )));
 
 }
 
-void KBlueTray::slotValidateLockDev(const QString& ubi)
+void KBlueTray::slotValidateLockDev(const QString& addr)
 {
-	if (ubi == lockDevice) {
+	if (addr == lockDevice) {
 		
 		kDebug() << "KBlueLock armed -- Lock Device disappeared";
 		QDBusConnection dbusconn = dbus->connectToBus(QDBusConnection::SessionBus, "dbus");
@@ -522,7 +545,7 @@ void KBlueTray::slotValidateLockDev(const QString& ubi)
 	 	}
 		
 
-		connect(adapter,SIGNAL(remoteDeviceFound(const QString&,int,int)),this,SLOT(slotTargetDeviceBack(const QString&,int,int)));
+	        connect(adapter,SIGNAL(deviceFound( const QString&, const QMap< QString,QVariant > & )),this,SLOT(slotTargetDeviceBack(const QString&, const QMap< QString,QVariant > & )));
 
 	}
 }
@@ -530,47 +553,46 @@ void KBlueTray::slotValidateLockDev(const QString& ubi)
 
 void KBlueTray::slotConfigureKBlueLock()
 {
-		if ( adapter->isPeriodicDiscoveryActive() ) 
-			adapter->stopPeriodicDiscovery();
-			kDebug() << "Periodic Discovery Stopped";
+                adapter->stopDiscovery();
+                kDebug() << "Periodic Discovery Stopped";
 			
 		kblueLockEnabled = false;
 
 		lockSelector = new DeviceSel(this,QString("computer,phone").split(','));
 		lockSelector->setOkButtonText("Select");
 		lockSelector->setInfoLabel(i18n("Selecting a device enables KBlueLock (a balloon message in the tray icon pops up when your target device is found and KBlueLock is ready).\nIf the device disappears your screen gets locked."));
-		connect(lockSelector,SIGNAL(deviceSelected(const QString&,const QString&)),this,SLOT(enableBlueLock(const QString&,const QString&)));
+		connect(lockSelector,SIGNAL(deviceSelected(const QString&)),this,SLOT(enableBlueLock(const QString&)));
 		connect(lockSelector,SIGNAL(selectorCancelled()),this,SLOT(slotBlueSelectorCancelled()));
 		connect(lockSelector,SIGNAL(unlockChanged(bool)),this,SLOT(slotUnlockScreenChanged(bool)));
-
 }
 
 
 void KBlueTray::slotBlueSelectorCancelled()
 {
 
-	disconnect(adapter,SIGNAL(remoteDeviceDisappeared(const QString)),this,SLOT(slotValidateLockDev(const QString&)));
-	disconnect(adapter,SIGNAL(remoteDeviceFound(const QString&,int,int)),this,SLOT(slotTargetDeviceFound(const QString&,int,int)));
+	disconnect(adapter,SIGNAL(deviceDisappeared(const QString&)),this,SLOT(slotValidateLockDev(const QString&)));
+	disconnect(adapter,SIGNAL(deviceFound( const QString&, const QMap< QString,QVariant > & )),this,SLOT(slotTargetDeviceFound(const QString&, const QMap< QString,QVariant > & )));
 	disconnect(lockSelector,0,0,0);
 	kblueLockEnabled = false;
-	enableBlueLock("",lockDevice);
+	enableBlueLock(lockDevice);
 
 }
-void KBlueTray::slotTargetDeviceFound(const QString& ubi,int /*dclass*/,int /*rssi*/)
+void KBlueTray::slotTargetDeviceFound(const QString& addr, const QMap< QString,QVariant > & props )
 {
-	if ((!kblueLockEnabled) && (ubi == lockDevice)) {
+	if ((!kblueLockEnabled) && (addr == lockDevice)) {
 		kDebug() << "Target device found - Kbluelock ready";
+                lockDeviceName = props["Name"].toString();
 		tray->showMessage("KBluetooth","kbluelock is enabled now");
 		kblueLockEnabled = true;
-		disconnect(adapter,SIGNAL(remoteDeviceFound(const QString&,int,int)),this,SLOT(slotTargetDeviceFound(const QString&,int,int)));
+	        disconnect(adapter,SIGNAL(deviceFound( const QString&, const QMap< QString,QVariant > & )),this,SLOT(slotTargetDeviceFound(const QString&, const QMap< QString,QVariant > & )));
 		updateTooltip();
 	}
 
 }
 
-void KBlueTray::slotTargetDeviceBack(const QString& ubi,int /*dclass*/,int /*rssi*/)
+void KBlueTray::slotTargetDeviceBack(const QString& addr, const QMap< QString,QVariant > & /* props */ )
 {
-	if ( (kblueLockEnabled && kblueUnlockEnabled ) && (ubi == lockDevice)) {
+	if ( (kblueLockEnabled && kblueUnlockEnabled ) && (addr == lockDevice)) {
 		kDebug() << "Target device is back. Disabling Screensaver.";
 
 		QDBusConnection dbusconn = dbus->connectToBus(QDBusConnection::SessionBus, "dbus");
@@ -597,7 +619,7 @@ void KBlueTray::slotTargetDeviceBack(const QString& ubi,int /*dclass*/,int /*rss
 			file.close();
 	 	}
 	
-		disconnect(adapter,SIGNAL(remoteDeviceFound(const QString&,int,int)),this,SLOT(slotTargetDeviceBack(const QString&,int,int)));
+	        disconnect(adapter,SIGNAL(deviceFound( const QString&, const QMap< QString,QVariant > & )),this,SLOT(slotTargetDeviceBack(const QString&, const QMap< QString,QVariant > & )));
 	}
 }
 
@@ -605,40 +627,23 @@ void KBlueTray::slotTargetDeviceBack(const QString& ubi,int /*dclass*/,int /*rss
 
 void KBlueTray::slotUnlockScreenChanged(bool val)
 {
-	kDebug() << "slotUnlockScreenChanged " << val;
-	kblueUnlockEnabled = val;
+    kDebug() << "slotUnlockScreenChanged " << val;
+    kblueUnlockEnabled = val;
 }
 
-
-void KBlueTray::slotModeChanged(Solid::Control::BluetoothInterface::Mode mode)
+void KBlueTray::slotPropertyChanged(const QString& prop, const QVariant& value)
 {
-	  kDebug() << "Adapter mode changed: " << modes.at(mode);
-	  updateTooltip();
+    kDebug() << "Property Changed: " << prop << value;
+    if (prop == "Name")
+        updateTooltip();
 }
 
-void KBlueTray::slotNameChanged(const QString& name)
-{
-	  kDebug() << "Adapter name changed: " << name;
-	  updateTooltip();
-}
-
-void KBlueTray::slotRemoteDeviceConnected(const QString& address)
-{
-	kDebug() << "Connection to " << address << "established";
-	tray->showMessage("KBluetooth",i18n("Connected to ") + adapter->getRemoteName(address));
-}
-
-void KBlueTray::slotRemoteDeviceDisconnected(const QString& address)
-{
-	kDebug() << "Disconnected from " << address << "lost";
-	tray->showMessage("KBluetooth",i18n("Disconnected from ") + adapter->getRemoteName(address));
-}
 
 //################### RECEIVE FILES #############################################
 
 void KBlueTray::slotServerReady() {
 	if(!server->isStarted())
-		server->start(QDir::homePath()+"/.kbluetooth4", true, true);
+		server->start(QDir::homePath()+"/.kbluetooth4", true, false);
 }
 
 void KBlueTray::slotServerErrorOccured(const QString& error_name, const QString& error_message) {
@@ -683,15 +688,10 @@ void KBlueTray::slotServerSessionCreated(const QString& path) {
 	serversession = new ObexServerSession(this, path);
 	connect(serversession, SIGNAL(disconnected()), this, SLOT(slotServerTransferDisconnected()));
 	
-	/*if(receiveFiles == 4) {
-		serversession->disconnect();
-		return;
-	}*/
+//	KDirSelectDialog dlg(KUrl("."), false, mainmenu);
+//	dlg.exec();
 	
-	/*KDirSelectDialog dlg(KUrl("."), false, mainmenu);
-	dlg.exec();
-	
-	kDebug() << dlg.url().url();*/
+//	kDebug() << dlg.url().url();
 	
 	connect(serversession, SIGNAL(transferStarted(const QString&, const QString&, qulonglong)), this, SLOT(slotServerSessionTransferStarted(const QString&, const QString&, qulonglong)));
 	connect(serversession, SIGNAL(transferProgress(qulonglong)), this, SLOT(slotTransferProgress(qulonglong)));
@@ -714,16 +714,16 @@ void KBlueTray::slotServerSessionRemoved(const QString& /*path*/) {
 
 void KBlueTray::slotServerSessionTransferStarted(const QString& filename, const QString& local_path, qulonglong total_bytes) {
 	
-	/*int receiveFiles = KMessageBox::questionYesNo(mainmenu, "Receive files over bluetooth?", "Incoming files over Bluetooth");
-	
+
+	int receiveFiles = KMessageBox::questionYesNo(mainmenu, "Receive files over bluetooth?", "Incoming files over Bluetooth");
+        kDebug() << "Receive Files? " << receiveFiles;
 	if(receiveFiles == 4) {
 		serversession->reject();
 		serversession->disconnect();
 		return;
-	}*/
-	
-	//serversession->accept();
-	
+	}
+        serversession->accept();
+
 	kDebug() << local_path;
 	kDebug() << total_bytes;
 	
@@ -731,7 +731,7 @@ void KBlueTray::slotServerSessionTransferStarted(const QString& filename, const
 	
 	progress = new QProgressDialog(i18n("Receiving ") + filename, i18n("Cancel"), 0, 100);
 	progress->setAutoClose(true);
-	progress->setWindowIcon(KIcon("preferences-system-bluetooth"));
+	progress->setWindowIcon(KIcon("kbluetooth4"));
 	progress->window()->setWindowTitle(i18n("Receiving ") + filename);
 	progress->show();
 	connect(progress, SIGNAL(canceled()), this, SLOT(slotFileReceiveCancelled()));
